==> wysiwyg_grammar_checker-7.x-1.1.tar.gz: wysiwyg_grammar_checker/proofread_bot.api.php <==
<?php
	
	function proofread_bot_check_api($text) {
		
		global $base_url;
		global $user;
		
		//print_r($user);
		if ($base_url == "http://proofreadbot.com") 	{
			$api = new DrupalREST('http://proofreadbot.com/server/');
			$api->debug = TRUE;
			
			if (user_is_logged_in())	{
				$api->session = session_name()."=".$user->sid;
			}
		}
		else {
			if (variable_get('proofread_bot_username'))
				define('PROOFREADBOT_USERNAME', variable_get('proofread_bot_username'));
			else
				return "Login failed, please check your Proofread Bot username and password in the <a href=\"". $base_url."/admin/config/content/proofread_bot\">admin screen</a>.";	
				
			if (variable_get('proofread_bot_password'))
				define('PROOFREADBOT_PASSWORD', variable_get('proofread_bot_password'));
			else
				return "Login failed, please check your Proofread Bot username and password in the <a href=\"". $base_url."/admin/config/content/proofread_bot\">admin screen</a>.";					

			$api = new DrupalREST('http://proofreadbot.com/server/', PROOFREADBOT_USERNAME, PROOFREADBOT_PASSWORD, TRUE);
			$api->login();
			
			//session is set to "=" if login failed :D, kind of hackish
			//print_r($api);
			if ($api->session == "=")
			return "Login failed, please check your Proofread Bot username and password in the <a href=\"". $base_url."/admin/config/system/proofread_bot\">admin screen</a>.";
			
		}
		
		$node = new stdClass();
		$node->type = 'proofreading';
		$node->language = "und";
		//if ($passed_data["type"] == "Full")
		//	$node->field_full[$node->language][0] = 1;
		//$node->field_depth[$node->language][0] = 2;
		
		$node->body[$node->language][0]["value"] = $text;
		$node->body[$node->language][0]["format"] = "filtered_html";
		
		
		$result = $api->createNode(array('node' => $node));

		//$result->nid = test nid here (must be integer;
		
		/*
			lets test this crappy encoding issue...	
			$result = $api->retrieveNode("700977");
		*/
		//print_r($result);
		$result_body = json_decode($result->body);

		if (isset($result_body->form_errors))
		{
			if (!$options['proofread_bot_username'] && !$options['proofread_bot_password'] && $base_url != "http://proofreadbot.com")
			//$result_body->form_errors->content .= "<br/>If you have already registered at <a href=\"http://proofreadbot.com/user\">proofreadbot.com/user</a> for a username and password, please enter them at the <a href=\"". $base_url."/admin/config/content/proofread_bot\">admin screen</a>.";
			//print_r($result_body->form_errors->content);		
			return $result_body->form_errors->content;
		}
		
		if (isset($result->nid))
		{
			$node = $api->retrieveNode($result->nid);	   
			return $node;
		}
	}
	
	
	class DrupalREST {
		var $username;
		var $password;
		var $session;
		var $endpoint;
		var $debug;
		
		function __construct($endpoint, $username, $password, $debug)
		{
			$this->username = $username;
			$this->password = $password;
			//TODO: Check for trailing slash and fix if needed
			$this->endpoint = $endpoint;
			$this->debug = $debug;
		}
		
		function login()
		{
			$ch = curl_init($this->endpoint . 'user/login.json');
			$post_data = array(
			'username' => $this->username,
			'password' => $this->password,
			);
			$post = http_build_query($post_data, '', '&');
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, false);
			curl_setopt($ch, CURLOPT_POST, true);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
			curl_setopt($ch, CURLOPT_HTTPHEADER,array (
            "Accept: application/json",
            "Content-type: application/x-www-form-urlencoded"
			));
			$response = json_decode(curl_exec($ch));
			
			curl_close($ch);
			
			//Save Session information to be sent as cookie with future calls
			$this->session = $response->session_name . '=' . $response->sessid;
		}
		
		// Retrieve a node from a node id
		function retrieveNode($nid)
		{
			//Cast node id as integer
			$nid = (int) $nid;
			$ch = curl_init($this->endpoint . 'node/' . $nid );
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, TRUE);
			curl_setopt($ch, CURLINFO_HEADER_OUT, TRUE);
			curl_setopt($ch, CURLOPT_HTTPHEADER,array (
			"Accept: application/json",
			"Cookie: $this->session"
			));
			$result = $this->_handleResponse($ch);
			
			curl_close($ch);
			
			return $result;
		}
		
		function createNode($node)
		{
			$post = http_build_query($node, '', '&');
			$ch = curl_init($this->endpoint . 'node/');
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
			curl_setopt($ch, CURLOPT_HEADER, TRUE);
			curl_setopt($ch, CURLOPT_POST, TRUE);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
			curl_setopt($ch, CURLOPT_HTTPHEADER,
			array (
			"Accept: application/json",
			"Content-type: application/x-www-form-urlencoded",
			"Cookie: $this->session"
			));
			
			$result = $this->_handleResponse($ch);
			
			curl_close($ch);
			
			return $result;
		}
		
		// Private Helper Functions
		private function _handleResponse($ch)
		{
			$response = curl_exec($ch);
			$info = curl_getinfo($ch);
			
			//break apart header & body
			$header = substr($response, 0, $info['header_size']);
			$body = substr($response, $info['header_size']);
			
			$result = new stdClass();
			
			if ($info['http_code'] != '200')
			{
				$header_arrray = explode("\n",$header);
				$result->ErrorCode = $info['http_code'];
				$result->ErrorText = $header_arrray['0'];
				} else {
				$result->ErrorCode = NULL;
				$decodedBody= json_decode($body);
				$result = (object) array_merge((array) $result, (array) $decodedBody );
			}
			
			if ($this->debug)
			{
				$result->header = $header;
				$result->body = $body;
			}
			
			return $result;
		}
	}
	
?>

==> wysiwyg_grammar_checker-7.x-1.3.tar.gz: wysiwyg_grammar_checker/proofread_bot.api.php <==
<?php
	
	function proofread_bot_check_api($text) {
		
		global $base_url;
		global $user;
		
		//print_r($user);
		if ($base_url == "http://proofreadbot.com" OR $base_url == "https://proofreadbot.com") 	{
			$api = new DrupalREST($base_url.'/server/');
			$api->debug = TRUE;
			
			if (user_is_logged_in())	{
				$api->session = session_name()."=".$user->sid;
			}
		}
		else {
			if (variable_get('proofread_bot_username'))
				define('PROOFREADBOT_USERNAME', variable_get('proofread_bot_username'));
			else
				return "Login failed, please check your Proofread Bot username and password in the <a href=\"". $base_url."/admin/config/content/proofread_bot\">admin screen</a>.";	
				
			if (variable_get('proofread_bot_password'))
				define('PROOFREADBOT_PASSWORD', variable_get('proofread_bot_password'));
			else
				return "Login failed, please check your Proofread Bot username and password in the <a href=\"". $base_url."/admin/config/content/proofread_bot\">admin screen</a>.";					

			$api = new DrupalREST('http://proofreadbot.com/server/', PROOFREADBOT_USERNAME, PROOFREADBOT_PASSWORD, TRUE);
			$api->login();
			
			//session is set to "=" if login failed :D, kind of hackish
			//print_r($api);
			if ($api->session == "=")
			return "Login failed, please check your Proofread Bot username and password in the <a href=\"". $base_url."/admin/config/system/proofread_bot\">admin screen</a>.";
			
		}
		
		$node = new stdClass();
		$node->type = 'proofreading';
		$node->language = "und";
		//if ($passed_data["type"] == "Full")
		//	$node->field_full[$node->language][0] = 1;
		//$node->field_depth[$node->language][0] = 2;
		
		$node->body[$node->language][0]["value"] = $text;
		$node->body[$node->language][0]["format"] = "filtered_html";
		
		
		$result = $api->createNode(array('node' => $node));

		//$result->nid = test nid here (must be integer;
		
		/*
			lets test this crappy encoding issue...	
			$result = $api->retrieveNode("700977");
		*/
		//print_r($result);
		$result_body = json_decode($result->body);

		if (isset($result_body->form_errors))
		{
			//if (!$options['proofread_bot_username'] && !$options['proofread_bot_password'] && $base_url != "http://proofreadbot.com")
			//$result_body->form_errors->content .= "<br/>If you have already registered at <a href=\"http://proofreadbot.com/user\">proofreadbot.com/user</a> for a username and password, please enter them at the <a href=\"". $base_url."/admin/config/content/proofread_bot\">admin screen</a>.";
			//print_r($result_body->form_errors->content);		
			return $result_body->form_errors->content;
		}
		
		if (isset($result->nid))
		{
			$node = $api->retrieveNode($result->nid);	   
			return $node;
		}
	}
	
	
	class DrupalREST {
		var $username;
		var $password;
		var $session;
		var $endpoint;
		var $debug;
		
		function __construct($endpoint, $username, $password, $debug)
		{
			$this->username = $username;
			$this->password = $password;
			//TODO: Check for trailing slash and fix if needed
			$this->endpoint = $endpoint;
			$this->debug = $debug;
		}
		
		function login()
		{
			$ch = curl_init($this->endpoint . 'user/login.json');
			$post_data = array(
			'username' => $this->username,
			'password' => $this->password,
			);
			$post = http_build_query($post_data, '', '&');
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, false);
			curl_setopt($ch, CURLOPT_POST, true);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
			curl_setopt($ch, CURLOPT_HTTPHEADER,array (
            "Accept: application/json",
            "Content-type: application/x-www-form-urlencoded"
			));
			$response = json_decode(curl_exec($ch));
			
			curl_close($ch);
			
			//Save Session information to be sent as cookie with future calls
			$this->session = $response->session_name . '=' . $response->sessid;
		}
		
		// Retrieve a node from a node id
		function retrieveNode($nid)
		{
			//Cast node id as integer
			$nid = (int) $nid;
			$ch = curl_init($this->endpoint . 'node/' . $nid );
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, TRUE);
			curl_setopt($ch, CURLINFO_HEADER_OUT, TRUE);
			curl_setopt($ch, CURLOPT_HTTPHEADER,array (
			"Accept: application/json",
			"Cookie: $this->session"
			));
			$result = $this->_handleResponse($ch);
			
			curl_close($ch);
			
			return $result;
		}
		
		function createNode($node)
		{
			$post = http_build_query($node, '', '&');
			$ch = curl_init($this->endpoint . 'node/');
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
			curl_setopt($ch, CURLOPT_HEADER, TRUE);
			curl_setopt($ch, CURLOPT_POST, TRUE);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
			curl_setopt($ch, CURLOPT_HTTPHEADER,
			array (
			"Accept: application/json",
			"Content-type: application/x-www-form-urlencoded",
			"Cookie: $this->session"
			));
			
			$result = $this->_handleResponse($ch);
			
			curl_close($ch);
			
			return $result;
		}
		
		// Private Helper Functions
		private function _handleResponse($ch)
		{
			$response = curl_exec($ch);
			$info = curl_getinfo($ch);
			
			//break apart header & body
			$header = substr($response, 0, $info['header_size']);
			$body = substr($response, $info['header_size']);
			
			$result = new stdClass();
			
			if ($info['http_code'] != '200')
			{
				$header_arrray = explode("\n",$header);
				$result->ErrorCode = $info['http_code'];
				$result->ErrorText = $header_arrray['0'];
				} else {
				$result->ErrorCode = NULL;
				$decodedBody= json_decode($body);
				$result = (object) array_merge((array) $result, (array) $decodedBody );
			}
			
			if ($this->debug)
			{
				$result->header = $header;
				$result->body = $body;
			}
			
			return $result;
		}
	}
	
?>
